/*
 * This file is part of the PocketSVG package.
 * Copyright (c) Ponderwell, Ariel Elkin, Fjölnir Ásgeirsson, and Contributors
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

#import <QuartzCore/QuartzCore.h>

NS_ASSUME_NONNULL_BEGIN

/// A CALayer subclass that renders an SVG file.
@interface SVGLayer : CALayer


/*!
 *  @discussion Initialises a layer that renders the provided SVG data.
 *
 *  @param svgSource The entire string of the XML document representing the SVG.
 *
 *  @code let url = NSBundle.mainBundle().URLForResource("svg_file_name", withExtension: "svg")!
 let svgSource = try! NSString(contentsOfURL: url, encoding: NSUTF8StringEncoding) as String

 let layer = SVGLayer(SVGSource: svgSource)
 // set the layer's frame and add it as a sublayer to display it.
 *
 */
- (instancetype)initWithSVGSource:(NSString *)svgSource NS_DESIGNATED_INITIALIZER;


/*!
 *  @discussion Initialises a layer that renders the SVG file at the URL.
 *
 *  @param url The URL of the SVG file.
 *
 *  @code let url = NSBundle.mainBundle().URLForResource("svg_file_name", withExtension: "svg")!
 let layer = SVGLayer(contentsOfURL: url)
 // set the layer's frame and add it as a sublayer to display it.
 *
 */
- (instancetype)initWithContentsOfURL:(NSURL *)url;


/*!
 *  @discussion Clears contents and renders a new SVG given the XML string of the SVG.
 *
 *  @param svgSource The XML string of an SVG.
 *
 */
@property(nonatomic, copy) NSString *svgSource;


/*!
 *  @discussion Clears contents and renders a new SVG given the file name of the SVG.
 *
 *  @param svgName The name of the SVG file (without the .svg suffix).
 *
 */
@property (nonatomic, copy) NSString *svgName;


/*!
 *  @discussion Renders a new SVG given the URL of an SVG file.
 *
 *  @param svgURL The XML string of an SVG.
 *
 */
@property (nonatomic, copy) NSURL *svgURL;


/*!
 *  @discussion Solidly fills the shape formed by the SVG path with the given color.
 *
 *  @param fillColor A color to fill the SVG shape with.
 *
 */
@property(nonatomic) CGColorRef fillColor;


/*!
 *  @discussion Solidly colors the path generated by the SVG file.
 *
 *  @param strokeColor The color to stroke the path with.
 *
 */
@property(nonatomic) CGColorRef strokeColor;


/*!
 *  @discussion Specifies whether or not line thickness should be scaled
 when scaling paths.
 *
 */
@property(nonatomic) BOOL scaleLineWidth;

@end
NS_ASSUME_NONNULL_END
